@@ -7,29 +7,33 @@ use crate::Box;
 
 #[test]
 fn test_box_trait_object() {
-    let four = Box::<dyn Display, [u8; 32]>::new(4);
+    let mut mem = [0; 32];
+    let four = Box::<dyn Display>::new(&mut mem, 4);
     assert_eq!(four.to_string(), "4");
     drop(four);
 
-    let seven = Box::<dyn Display, [u8; 32]>::new(7);
+    let seven = Box::<dyn Display>::new(&mut mem, 7);
     assert_eq!(seven.to_string(), "7");
 }
 
 #[test]
 fn test_box_move() {
-    fn move_me(b: Box<dyn Display, [u8; 32]>) {
+    fn move_me(b: Box<dyn Display>) {
         assert_eq!(b.to_string(), "42");
     }
 
-    fn move_from_box() -> Box<dyn Display, [u8; 32]> {
-        Box::<dyn Display, [u8; 32]>::new(42)
+    fn move_from_box() -> Box<'static, dyn Display> {
+        static mut STATIC_MEM: [u8; 32] = [0; 32];
+
+        Box::<dyn Display>::new(unsafe { STATIC_MEM.as_mut() }, 42)
     }
 
-    struct MyStruct {
-        display: Box<dyn Display, [u8; 32]>,
+    struct MyStruct<'a> {
+        display: Box<'a, dyn Display>,
     }
 
-    let b = Box::<dyn Display, [u8; 32]>::new(42);
+    let mut mem = [0; 32];
+    let b = Box::<dyn Display>::new(&mut mem, 42);
     move_me(b);
 
     let x = move_from_box();
@@ -42,7 +46,8 @@ fn test_box_move() {
 #[test]
 #[should_panic(expected = "Not enough memory")]
 fn test_box_insufficient_memory() {
-    let _four = Box::<dyn Display, [u8; 2]>::new(4);
+    let mut mem = [0; 2];
+    let _four = Box::<dyn Display>::new(&mut mem, 4);
 }
 
 #[test]
@@ -59,28 +64,21 @@ fn test_drop() {
     }
 
     let (tx, rx) = mpsc::channel();
-    let b = Box::<dyn Debug, [u8; 32]>::new(Foo { tx });
+    let mut mem = [0; 32];
+    let b = Box::<dyn Debug>::new(&mut mem, Foo { tx });
     drop(b);
 
     assert_eq!(rx.recv().unwrap(), 42);
 }
 
-#[test]
-fn test_box_in_provided_memory() {
-    let mut mem = [0_u8; 32];
-
-    let val: Box<dyn Display, _> = Box::new_in_buf(&mut mem, 42);
-    assert_eq!(val.to_string(), "42");
-}
-
 #[test]
 fn test_layout_of_dyn_vec() {
     let value = 42_u64;
 
-    let layout = Box::<dyn Display, &mut [u8]>::layout_of_dyn(&value);
+    let layout = Box::<dyn Display>::layout_of_dyn(&value);
     let mut mem = vec![0_u8; layout.size() + layout.align()];
 
-    let val: Box<dyn Display, _> = Box::new_in_buf(&mut mem, value);
+    let val: Box<dyn Display> = Box::new(&mut mem, value);
     assert_eq!(val.to_string(), "42");
 }
 
@@ -91,13 +89,13 @@ fn test_layout_of_dyn_split_at_mut() {
     let value = 42_u64;
 
     let total_len = {
-        let layout = Box::<dyn Display, &mut [u8]>::layout_of_dyn(&value);
+        let layout = Box::<dyn Display>::layout_of_dyn(&value);
         let align_offset = mem.as_ptr().align_offset(layout.align());
         layout.size() + align_offset
     };
     let (head, _tail) = mem.split_at_mut(total_len);
 
-    let val: Box<dyn Display, _> = Box::new_in_buf(head, value);
+    let val: Box<dyn Display> = Box::new(head, value);
     assert_eq!(val.to_string(), "42");
 }
 
@@ -105,7 +103,9 @@ fn test_layout_of_dyn_split_at_mut() {
 fn test_box_dyn_fn() {
     let a = 42;
     let closure = move || a;
-    let b = Box::<dyn Fn() -> i32, [u8; 64]>::new(closure);
+
+    let mut mem = [0; 64];
+    let b = Box::<dyn Fn() -> i32>::new(&mut mem, closure);
     assert_eq!(b(), 42);
 }
 
@@ -113,7 +113,8 @@ fn test_box_dyn_fn() {
 fn test_box_nested_dyn_fn() {
     let closure = move |d: &dyn Fn(i32) -> String| d(42);
 
-    let b = Box::<dyn Fn(&dyn Fn(i32) -> String) -> String, [u8; 32]>::new(closure);
+    let mut mem = [0; 32];
+    let b = Box::<dyn Fn(&dyn Fn(i32) -> String) -> String>::new(&mut mem, closure);
     assert_eq!(b(&|a| a.to_string()), "42");
 }
 
@@ -121,16 +122,17 @@ fn test_box_nested_dyn_fn() {
 fn test_box_in_unaligned_memory() {
     let mut mem = [0_u8; 128];
 
-    let val: Box<dyn Display, _> = Box::new_in_buf(&mut mem[3..], 42);
+    let val: Box<dyn Display> = Box::new(&mut mem[3..], 42);
     assert_eq!(val.to_string(), "42");
 }
 
 #[test]
 fn test_box_in_static_mem() {
-    static mut BOX: Option<Box<dyn Display, [u8; 32]>> = None;
+    static mut MEM: [u8; 32] = [0; 32];
+    static mut BOX: Option<Box<dyn Display>> = None;
 
     unsafe {
-        BOX.replace(Box::<dyn Display, [u8; 32]>::new(42));
+        BOX.replace(Box::<dyn Display>::new(&mut MEM, 42));
         assert_eq!(BOX.as_ref().unwrap().to_string(), "42");
     }
 }
